@@ -7,11 +7,12 @@ use Moose::Util::TypeConstraints;
 
 extends qw|Text::vCard::Precisely::V3::Node::Tel Text::vCard::Precisely::V4::Node|;
 
-subtype 'v4Tel'
-    => as 'Str'
-    => where { m/^(?:tel:)?(?:[+]?\d{1,2}|\d*)[\(\s\-]?\d{1,3}[\)\s\-]?[\s]?\d{1,3}[\s\-]?\d{3,4}$/s }
-    => message { "The Number you provided, $_, was not supported in Tel" };
-has content => (is => 'ro', default => '', isa => 'v4Tel' );
+#   to validate phone numbers is too difficult for me
+#subtype 'v4Tel'
+#    => as 'Str'
+#    => where { m/^(?:tel:)?(?:[+]?\d{1,2}|\d*)[\(\s\-]?\d{1,3}[\)\s\-]?[\s]?\d{1,3}[\s\-]?\d{3,4}$/s }
+#    => message { "The Number you provided, $_, was not supported in Tel" };
+has content => (is => 'ro', default => '', isa => 'Str' );
 
 override 'as_string' => sub {
     my ($self) = @_;
@@ -30,8 +31,6 @@ override 'as_string' => sub {
     return $self->fold( $string, -force => 1 );
 };
 
-
-
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
